/************************************************************************
Name: getopt.c
DESCRITPTION: gets options and passes them to flecs90
DATE: August 24, 1994
*************************************************************************/

/* INCLUDE FILES */
#include "flecs90.h"

/* FUNCTION DEFINITION */
int main(int argc,char *argv[])
/* ARGUEMENTS */
/* OPTIONAL */
/* 1. -f : FORTRAN output file will not be written */
/* 2. -c : Comments in flecs source code will be written to FORTRAN
           code file */
/* 3. -n : Line numbers corresponding to the line of the flecs
           source code will be included in the fortran output file */
/* 4. -s : Translate Flecs keywords SELECT (ref_spec) and 
           CASE (ref_spec) into fortran SELECT CASE statements */
/* 5. -l : Do not label DO loops procedured by FLECS.
           WARNING: CYCLE and EXIT statements will apply to inner most
	   fortran or flecs loop *NOT* neccsarily flecs loop */

/* REQUIRED */
/* 6. <file> : Name of input file from which flecs source code
               will be read. */


{
/* VARIABLES */

  /* External */
  extern char *keyword[NKEYS+1];   /* Array of character strings which define
			       flecs keywords */
  extern char *prog_name;   /* name of program */
  extern int qcomment;      /* if true comments in flecs source code
                               will be writen to fortran code file */
  extern int qfortran;      /* if true a fortran output file is
                               produced */
  extern int qline;         /* if true line numbers corresponding
			       to the line in the flecs source file
			       will be written in columns 74 to 79
			       of the fortran code */
  extern int qlabel;        /* if false flecs loops will not be labeled */

  /* Local */
  int i,j;                  /* loop control variables */
  int len;                  /* length of option */

  /* BEGIN CODE */

  prog_name = argv[0];
  if (argc <= 1) {
    fprintf(stderr,"usage: %s [-f] [-c] [-n] [-s] [-l] file ...\n",prog_name);
    fprintf(stderr,"\n  -f : Process FLECS file but do not create a Fortran file.\n");
    fprintf(stderr,"  -c : Echo comments in FLECS file to Fortran file.\n");
    fprintf(stderr,"  -n : Include line number of FLECS code in columns 74 to 78\n       of Fortran file.\n");
    fprintf(stderr,"  -s : Translate FLECS SELECT and appropriate CASE statements into\n       Fortran 90 SELECT CASE rather than BLOCK-IF statements.\n");
    fprintf(stderr,"  -l : Do not include a label in Fortran 90 translation naming DO\n       loops generated by FLECS repetition keywords.\n");
    exit(1);
  }
  qfortran = 1;
  qlabel = 1;
  qcomment = 0;
  qline = 0;
  qselect = 0;

  i = 1;
  /* Determine options */
  while (i < argc) {
    if (*argv[i] == '-') {
      len = length(argv[i]);
      argv[i]++;
      for (j=1; j < len; j++) {
	if (*argv[i] == 'f') qfortran = 0;
	else if (*argv[i] == 'c') qcomment = 1;
	else if (*argv[i] == 'n') qline = 1;
	else if (*argv[i] == 's') qselect = 1;
	else if (*argv[i] == 'l') qlabel = 0;
	else {
	  fprintf(stderr,"%s: invalid option == %c\n",prog_name,*argv[i]);
	  fprintf(stderr,"usage: %s [-f] [-c] [-n] [-s] [-l] file ...\n",
		  prog_name);
	  exit(1);
	}
	argv[i]++;
      }
      i++;
    } else break;
  }
  if (!qfortran) {
    qcomment = 0;
    qline = 0;
  }


  /* Set value of Constant Variable keyword */
  keyword[0] = "";
  keyword[1] = "REPEAT WHILE";
  keyword[2] = "REPEAT UNTIL";
  keyword[3] = "DO";
  keyword[4] = "END";
  keyword[5] = "CASE";
  keyword[6] = "CASE";
  keyword[7] = "ENDIF";
  keyword[8] = "FOR";
  keyword[9] = "WHILE";
  keyword[10] = "UNTIL";
  keyword[11] = "LOOP";
  keyword[12] = "IF";
  keyword[13] = "UNLESS";
  keyword[14] = "WHEN";
  keyword[15] = "ELSE";
  keyword[16] = "TO";
  keyword[17] = "CONDITIONAL";
  keyword[18] = "SELECT";
  keyword[19] = "FIN";
  keyword[20] = "CYCLE";
  keyword[21] = "EXIT";
  keyword[22] = "REVERT";
  keyword[23] = "INSTANCE";
  keyword[24] = "OTHERWISE";
  keyword[25] = "PROCEDURE CALL";
  keyword[26] = "IFTHEN";

  /* Loop through each file name */
  for (j=i; j < argc; j++) flecs90(argv[j]);

  /* Exit */
  exit(0);
}
